PollResult

Enum PollResult 

pub enum PollResult<K: Debug> {
    Ready(K),
    NotReady(Option<Duration>),
}
Represents result from MultiBufBatch.poll() function call.

Variants



Ready(K)

Batch K is ready after reaching one of the limits.



NotReady(Option<Duration>)

No outstanding batch has not reached one of its limits yet. Provides Duration after which max_duration limit will be reached if there is at least one outstanding batch.